/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.ow2.petals.kernel.api.server;


/**
 * @author Roland NAUDIN - EBM WebSourcing
 * @since PEtALS 2.2
 */
public interface PetalsServer {
    
    static final String WORK_DIRECTORY = "work";
    
    static final String INSTALL_DIRECTORY = "install";
    
    static final String INSTALLED_DIRECTORY = "installed";

    /**
     * Initialize the PEtALS environment
     *
     * @throws PetalsException
     *             Raised if any error during initialization
     */
    void init() throws PetalsException;

    /**
     * Start the PEtALS container
     *
     * @throws PetalsException
     *             Raised if any error during starting
     */
    void start() throws PetalsException;

    /**
     * Stop the PEtALS container.
     *
     * @throws PetalsException
     *             Raised if any error during stopping
     */
    void stop() throws PetalsException;

    /**
     * Add a PetalsStateListener to the PEtALS server.
     *
     * @param petalsListener
     *            The listener to register
     */
    void addPetalsStateListener(PetalsStateListener petalsListener);

    /**
     * Remove a PetalsStateListener from the PEtALS server.
     *
     * @param petalsListener
     *            The listener to unregister
     * @return {@code true} is the listener was registered and have been
     *         removed, {@code false} otherwise
     */
    boolean removePetalsStateListener(PetalsStateListener petalsListener);

    /**
     * Browse the content of the PEtALS JNDI directory.
     *
     * @return A Content in a String form
     * @throws PetalsException
     *             Raised if any error during browsing
     */
    String browseJNDI() throws PetalsException;

    /**
     * Get the container configuration. Must be called once the PEtALS container
     * is started.
     *
     * @return The container configuration in a String form
     * @throws PetalsException
     *             If the container configuration is not defined
     */
    String getContainerConfiguration() throws PetalsException;

}
